@@ -32,6 +32,7 @@ pub const MOVE_FOCUS_DOWN_IN_PANE_MODE: [u8; 1] = [106]; // j
 pub const MOVE_FOCUS_UP_IN_PANE_MODE: [u8; 1] = [107]; // k
 pub const MOVE_FOCUS_LEFT_IN_PANE_MODE: [u8; 1] = [104]; // h
 pub const MOVE_FOCUS_RIGHT_IN_PANE_MODE: [u8; 1] = [108]; // l
+pub const RENAME_PANE_MODE: [u8; 1] = [99]; // c
 
 pub const SCROLL_MODE: [u8; 1] = [19]; // ctrl-s
 pub const SCROLL_UP_IN_SCROLL_MODE: [u8; 1] = [107]; // k
@@ -51,6 +52,7 @@ pub const NEW_TAB_IN_TAB_MODE: [u8; 1] = [110]; // n
 pub const SWITCH_NEXT_TAB_IN_TAB_MODE: [u8; 1] = [108]; // l
 pub const SWITCH_PREV_TAB_IN_TAB_MODE: [u8; 1] = [104]; // h
 pub const CLOSE_TAB_IN_TAB_MODE: [u8; 1] = [120]; // x
+pub const RENAME_TAB_MODE: [u8; 1] = [114]; // r
 
 pub const SESSION_MODE: [u8; 1] = [15]; // ctrl-o
 pub const DETACH_IN_SESSION_MODE: [u8; 1] = [100]; // d
@@ -206,7 +208,6 @@ pub fn scrolling_inside_a_pane() {
     let last_snapshot = loop {
         RemoteRunner::kill_running_sessions(fake_win_size);
         let mut runner = RemoteRunner::new(fake_win_size)
-            .retry_pause_ms(1000) // we need a longer retry period here because it takes some time to fill the pty buffer
             .add_step(Step {
                 name: "Split pane to the right",
                 instruction: |mut remote_terminal: RemoteTerminal| -> bool {
@@ -227,32 +228,7 @@ pub fn scrolling_inside_a_pane() {
                     let mut step_is_complete = false;
                     if remote_terminal.cursor_position_is(63, 2) && remote_terminal.tip_appears() {
                         // cursor is in the newly opened second pane
-                        let mut content_to_send = String::new();
-                        write!(&mut content_to_send, "{:0<56}", "line1 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line2 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line3 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line4 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line5 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line6 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line7 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line8 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line9 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line10 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line11 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line12 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line13 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line14 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line15 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line16 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line17 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line18 ").unwrap();
-                        write!(&mut content_to_send, "{:0<58}", "line19 ").unwrap();
-                        write!(&mut content_to_send, "{:0<57}", "line20 ").unwrap();
-
-                        remote_terminal.send_key(&BRACKETED_PASTE_START);
-                        remote_terminal.send_key(content_to_send.as_bytes());
-                        remote_terminal.send_key(&BRACKETED_PASTE_END);
-
+                        remote_terminal.load_fixture("e2e/scrolling_inside_a_pane");
                         step_is_complete = true;
                     }
                     step_is_complete
@@ -262,7 +238,9 @@ pub fn scrolling_inside_a_pane() {
                 name: "Scroll up inside pane",
                 instruction: |mut remote_terminal: RemoteTerminal| -> bool {
                     let mut step_is_complete = false;
-                    if remote_terminal.cursor_position_is(118, 20) {
+                    if remote_terminal.cursor_position_is(63, 20)
+                        && remote_terminal.snapshot_contains("line21")
+                    {
                         // all lines have been written to the pane
                         remote_terminal.send_key(&SCROLL_MODE);
                         remote_terminal.send_key(&SCROLL_UP_IN_SCROLL_MODE);
@@ -276,10 +254,11 @@ pub fn scrolling_inside_a_pane() {
             name: "Wait for scroll to finish",
             instruction: |remote_terminal: RemoteTerminal| -> bool {
                 let mut step_is_complete = false;
-                if remote_terminal.cursor_position_is(118, 20)
-                    && remote_terminal.snapshot_contains("line1 ")
+                if remote_terminal.cursor_position_is(63, 20)
+                    && remote_terminal.snapshot_contains("line3 ")
+                    && remote_terminal.snapshot_contains("SCROLL:  1/4")
                 {
-                    // scrolled up one line
+                    // keyboard scrolls up 1 line, scrollback is 4 lines: cat command + 2 extra lines from fixture + prompt
                     step_is_complete = true;
                 }
                 step_is_complete
@@ -1004,6 +983,41 @@ pub fn accepts_basic_layout() {
     assert_snapshot!(last_snapshot);
 }
 
+#[test]
+#[ignore]
+pub fn status_bar_loads_custom_keybindings() {
+    let fake_win_size = Size {
+        cols: 120,
+        rows: 24,
+    };
+    let config_file_name = "changed_keys.yaml";
+    let mut test_attempts = 10;
+    let last_snapshot = loop {
+        RemoteRunner::kill_running_sessions(fake_win_size);
+        let mut runner = RemoteRunner::new_with_config(fake_win_size, config_file_name);
+        runner.run_all_steps();
+        let last_snapshot = runner.take_snapshot_after(Step {
+            name: "Wait for app to load",
+            instruction: |remote_terminal: RemoteTerminal| -> bool {
+                let mut step_is_complete = false;
+                if remote_terminal.cursor_position_is(3, 1)
+                    && remote_terminal.snapshot_contains("$ █                   ││$")
+                    && remote_terminal.snapshot_contains("$                                                                                                                     ") {
+                    step_is_complete = true;
+                }
+                step_is_complete
+            },
+        });
+        if runner.test_timed_out && test_attempts > 0 {
+            test_attempts -= 1;
+            continue;
+        } else {
+            break last_snapshot;
+        }
+    };
+    assert_snapshot!(last_snapshot);
+}
+
 #[test]
 #[ignore]
 fn focus_pane_with_mouse() {
@@ -1074,7 +1088,6 @@ pub fn scrolling_inside_a_pane_with_mouse() {
     let last_snapshot = loop {
         RemoteRunner::kill_running_sessions(fake_win_size);
         let mut runner = RemoteRunner::new(fake_win_size)
-            .retry_pause_ms(1000) // we need a longer retry period here because it takes some time to fill the pty buffer
             .add_step(Step {
                 name: "Split pane to the right",
                 instruction: |mut remote_terminal: RemoteTerminal| -> bool {
@@ -1094,27 +1107,7 @@ pub fn scrolling_inside_a_pane_with_mouse() {
                 instruction: |mut remote_terminal: RemoteTerminal| -> bool {
                     let mut step_is_complete = false;
                     if remote_terminal.cursor_position_is(63, 2) && remote_terminal.tip_appears() {
-                        // cursor is in the newly opened second pane
-                        remote_terminal.send_key(format!("{:0<56}", "line1 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line2 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line3 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line4 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line5 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line6 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line7 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line8 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line9 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line10 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line11 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line12 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line13 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line14 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line15 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line16 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line17 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line18 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<58}", "line19 ").as_bytes());
-                        remote_terminal.send_key(format!("{:0<57}", "line20 ").as_bytes());
+                        remote_terminal.load_fixture("e2e/scrolling_inside_a_pane");
                         step_is_complete = true;
                     }
                     step_is_complete
@@ -1124,7 +1117,9 @@ pub fn scrolling_inside_a_pane_with_mouse() {
                 name: "Scroll up inside pane",
                 instruction: |mut remote_terminal: RemoteTerminal| -> bool {
                     let mut step_is_complete = false;
-                    if remote_terminal.cursor_position_is(118, 20) {
+                    if remote_terminal.cursor_position_is(63, 20)
+                        && remote_terminal.snapshot_contains("line21")
+                    {
                         // all lines have been written to the pane
                         remote_terminal.send_key(&sgr_mouse_report(Position::new(2, 64), 64));
                         step_is_complete = true;
@@ -1137,10 +1132,11 @@ pub fn scrolling_inside_a_pane_with_mouse() {
             name: "Wait for scroll to finish",
             instruction: |remote_terminal: RemoteTerminal| -> bool {
                 let mut step_is_complete = false;
-                if remote_terminal.cursor_position_is(118, 20)
+                if remote_terminal.cursor_position_is(63, 20)
                     && remote_terminal.snapshot_contains("line1 ")
+                    && remote_terminal.snapshot_contains("SCROLL:  3/4")
                 {
-                    // scrolled up one line
+                    // mouse wheel scrolls up 3 lines, scrollback is 4 lines: cat command + 2 extra lines from fixture + prompt
                     step_is_complete = true;
                 }
                 step_is_complete
@@ -1853,3 +1849,102 @@ pub fn edit_scrollback() {
     };
     assert!(last_snapshot.contains(".dump"));
 }
+
+#[test]
+#[ignore]
+pub fn undo_rename_tab() {
+    let fake_win_size = Size {
+        cols: 120,
+        rows: 24,
+    };
+
+    let mut test_attempts = 10;
+    let last_snapshot = loop {
+        RemoteRunner::kill_running_sessions(fake_win_size);
+        let mut runner = RemoteRunner::new(fake_win_size).add_step(Step {
+            name: "Undo tab name change",
+            instruction: |mut remote_terminal: RemoteTerminal| -> bool {
+                let mut step_is_complete = false;
+                if remote_terminal.status_bar_appears()
+                    && remote_terminal.snapshot_contains("Tab #1")
+                {
+                    remote_terminal.send_key(&TAB_MODE);
+                    remote_terminal.send_key(&RENAME_TAB_MODE);
+                    remote_terminal.send_key(&[97, 97]);
+                    remote_terminal.send_key(&ESC);
+                    step_is_complete = true;
+                }
+                step_is_complete
+            },
+        });
+        runner.run_all_steps();
+
+        let last_snapshot = runner.take_snapshot_after(Step {
+            name: "Wait for tab name to apper on screen",
+            instruction: |remote_terminal: RemoteTerminal| -> bool {
+                let mut step_is_complete = false;
+                if remote_terminal.snapshot_contains("Tab #1") {
+                    step_is_complete = true
+                }
+                step_is_complete
+            },
+        });
+
+        if runner.test_timed_out && test_attempts > 0 {
+            test_attempts -= 1;
+            continue;
+        } else {
+            break last_snapshot;
+        }
+    };
+    assert_snapshot!(last_snapshot);
+}
+
+#[test]
+#[ignore]
+pub fn undo_rename_pane() {
+    let fake_win_size = Size {
+        cols: 120,
+        rows: 24,
+    };
+
+    let mut test_attempts = 10;
+    let last_snapshot = loop {
+        RemoteRunner::kill_running_sessions(fake_win_size);
+        let mut runner = RemoteRunner::new(fake_win_size).add_step(Step {
+            name: "Undo pane name change",
+            instruction: |mut remote_terminal: RemoteTerminal| -> bool {
+                let mut step_is_complete = false;
+                if remote_terminal.status_bar_appears() && remote_terminal.cursor_position_is(3, 2)
+                {
+                    remote_terminal.send_key(&PANE_MODE);
+                    remote_terminal.send_key(&RENAME_PANE_MODE);
+                    remote_terminal.send_key(&[97, 97]);
+                    remote_terminal.send_key(&ESC);
+                    step_is_complete = true;
+                }
+                step_is_complete
+            },
+        });
+        runner.run_all_steps();
+
+        let last_snapshot = runner.take_snapshot_after(Step {
+            name: "Wait for pane name to apper on screen",
+            instruction: |remote_terminal: RemoteTerminal| -> bool {
+                let mut step_is_complete = false;
+                if remote_terminal.snapshot_contains("Pane #1") {
+                    step_is_complete = true
+                }
+                step_is_complete
+            },
+        });
+
+        if runner.test_timed_out && test_attempts > 0 {
+            test_attempts -= 1;
+            continue;
+        } else {
+            break last_snapshot;
+        }
+    };
+    assert_snapshot!(last_snapshot);
+}
