@@ -1,27 +1,29 @@
 pub mod os_input_output;
 
 mod command_is_executing;
+pub mod fake_client;
 mod input_handler;
+mod sessions;
 mod stdin_ansi_parser;
 mod stdin_handler;
 
-use log::error;
 use log::info;
 use std::env::current_exe;
 use std::io::{self, Write};
 use std::path::Path;
 use std::process::Command;
+use std::sync::{Arc, Mutex};
 use std::thread;
-use zellij_tile::prelude::Style;
 
+use crate::stdin_ansi_parser::{AnsiStdinInstruction, StdinAnsiParser};
 use crate::{
     command_is_executing::CommandIsExecuting, input_handler::input_loop,
     os_input_output::ClientOsApi, stdin_handler::stdin_loop,
 };
-use zellij_tile::data::InputMode;
 use zellij_utils::{
     channels::{self, ChannelWithContext, SenderWithContext},
     consts::ZELLIJ_IPC_PIPE,
+    data::{ClientId, InputMode, Style},
     envs,
     errors::{ClientContext, ContextType, ErrorInstruction},
     input::{actions::Action, config::Config, options::Options},
@@ -39,6 +41,7 @@ pub(crate) enum ClientInstruction {
     Exit(ExitReason),
     SwitchToMode(InputMode),
     Connected,
+    ActiveClients(Vec<ClientId>),
 }
 
 impl From<ServerToClientMsg> for ClientInstruction {
@@ -49,8 +52,9 @@ impl From<ServerToClientMsg> for ClientInstruction {
             ServerToClientMsg::UnblockInputThread => ClientInstruction::UnblockInputThread,
             ServerToClientMsg::SwitchToMode(input_mode) => {
                 ClientInstruction::SwitchToMode(input_mode)
-            }
+            },
             ServerToClientMsg::Connected => ClientInstruction::Connected,
+            ServerToClientMsg::ActiveClients(clients) => ClientInstruction::ActiveClients(clients),
         }
     }
 }
@@ -64,6 +68,7 @@ impl From<&ClientInstruction> for ClientContext {
             ClientInstruction::UnblockInputThread => ClientContext::UnblockInputThread,
             ClientInstruction::SwitchToMode(_) => ClientContext::SwitchToMode,
             ClientInstruction::Connected => ClientContext::Connected,
+            ClientInstruction::ActiveClients(_) => ClientContext::ActiveClients,
         }
     }
 }
@@ -110,7 +115,7 @@ impl ClientInfo {
 pub(crate) enum InputInstruction {
     KeyEvent(InputEvent, Vec<u8>),
     SwitchToMode(InputMode),
-    PossiblePixelRatioChange,
+    AnsiStdinInstructions(Vec<AnsiStdinInstruction>),
 }
 
 pub fn start_client(
@@ -122,7 +127,7 @@ pub fn start_client(
     layout: Option<LayoutFromYaml>,
 ) {
     info!("Starting Zellij client!");
-    let clear_client_terminal_attributes = "\u{1b}[?1l\u{1b}=\u{1b}[r\u{1b}12l\u{1b}[?1000l\u{1b}[?1002l\u{1b}[?1003l\u{1b}[?1005l\u{1b}[?1006l\u{1b}[?12l";
+    let clear_client_terminal_attributes = "\u{1b}[?1l\u{1b}=\u{1b}[r\u{1b}[?1000l\u{1b}[?1002l\u{1b}[?1003l\u{1b}[?1005l\u{1b}[?1006l\u{1b}[?12l";
     let take_snapshot = "\u{1b}[?1049h";
     let bracketed_paste = "\u{1b}[?2004h";
     os_input.unset_raw_mode(0).unwrap();
@@ -153,16 +158,19 @@ pub fn start_client(
             colors: palette,
             rounded_corners: config.ui.unwrap_or_default().pane_frames.rounded_corners,
         },
+        keybinds: config.keybinds.clone(),
     };
 
     let first_msg = match info {
         ClientInfo::Attach(name, config_options) => {
             envs::set_session_name(name);
+            envs::set_initial_environment_vars();
 
             ClientToServerMsg::AttachClient(client_attributes, config_options)
-        }
+        },
         ClientInfo::New(name) => {
             envs::set_session_name(name);
+            envs::set_initial_environment_vars();
 
             spawn_server(&*ZELLIJ_IPC_PIPE).unwrap();
 
@@ -173,7 +181,7 @@ pub fn start_client(
                 Box::new(layout.unwrap()),
                 Some(config.plugins.clone()),
             )
-        }
+        },
     };
 
     os_input.connect_to_server(&*ZELLIJ_IPC_PIPE);
@@ -202,7 +210,6 @@ pub fn start_client(
         let send_client_instructions = send_client_instructions.clone();
         let os_input = os_input.clone();
         Box::new(move |info| {
-            error!("Panic occured in client:\n{:?}", info);
             if let Ok(()) = os_input.unset_raw_mode(0) {
                 handle_panic(info, &send_client_instructions);
             }
@@ -210,13 +217,15 @@ pub fn start_client(
     });
 
     let on_force_close = config_options.on_force_close.unwrap_or_default();
+    let stdin_ansi_parser = Arc::new(Mutex::new(StdinAnsiParser::new()));
 
     let _stdin_thread = thread::Builder::new()
         .name("stdin_handler".to_string())
         .spawn({
             let os_input = os_input.clone();
             let send_input_instructions = send_input_instructions.clone();
-            move || stdin_loop(os_input, send_input_instructions)
+            let stdin_ansi_parser = stdin_ansi_parser.clone();
+            move || stdin_loop(os_input, send_input_instructions, stdin_ansi_parser)
         });
 
     let _input_thread = thread::Builder::new()
@@ -242,7 +251,6 @@ pub fn start_client(
     let _signal_thread = thread::Builder::new()
         .name("signal_listener".to_string())
         .spawn({
-            let send_input_instructions = send_input_instructions.clone();
             let os_input = os_input.clone();
             move || {
                 os_input.handle_signals(
@@ -252,14 +260,25 @@ pub fn start_client(
                             os_api.send_to_server(ClientToServerMsg::TerminalResize(
                                 os_api.get_terminal_size_using_fd(0),
                             ));
-                            let _ = send_input_instructions
-                                .send(InputInstruction::PossiblePixelRatioChange);
+                            // send a query to the terminal emulator in case the font size changed
+                            // as well - we'll parse the response through STDIN
+                            let terminal_emulator_query_string = stdin_ansi_parser
+                                .lock()
+                                .unwrap()
+                                .window_size_change_query_string();
+                            let _ = os_api
+                                .get_stdout_writer()
+                                .write(terminal_emulator_query_string.as_bytes())
+                                .unwrap();
                         }
                     }),
                     Box::new({
                         let os_api = os_input.clone();
                         move || {
-                            os_api.send_to_server(ClientToServerMsg::Action(on_force_close.into()));
+                            os_api.send_to_server(ClientToServerMsg::Action(
+                                on_force_close.into(),
+                                None,
+                            ));
                         }
                     }),
                 );
@@ -283,13 +302,19 @@ pub fn start_client(
                         if should_break {
                             break;
                         }
-                    }
+                    },
                     None => {
                         send_client_instructions
                             .send(ClientInstruction::UnblockInputThread)
                             .unwrap();
                         log::error!("Received empty message from server");
-                    }
+                        send_client_instructions
+                            .send(ClientInstruction::Error(
+                                "Received empty message from server".to_string(),
+                            ))
+                            .unwrap();
+                        break;
+                    },
                 }
             }
         })
@@ -301,7 +326,7 @@ pub fn start_client(
         let restore_snapshot = "\u{1b}[?1049l";
         os_input.disable_mouse();
         let error = format!(
-            "{}\n{}{}",
+            "{}\n{}{}\n",
             restore_snapshot, goto_start_of_last_line, backtrace
         );
         let _ = os_input
@@ -329,27 +354,27 @@ pub fn start_client(
                 }
                 exit_msg = reason.to_string();
                 break;
-            }
+            },
             ClientInstruction::Error(backtrace) => {
-                let _ = os_input.send_to_server(ClientToServerMsg::Action(Action::Quit));
+                let _ = os_input.send_to_server(ClientToServerMsg::Action(Action::Quit, None));
                 handle_error(backtrace);
-            }
+            },
             ClientInstruction::Render(output) => {
                 let mut stdout = os_input.get_stdout_writer();
                 stdout
                     .write_all(output.as_bytes())
                     .expect("cannot write to stdout");
                 stdout.flush().expect("could not flush");
-            }
+            },
             ClientInstruction::UnblockInputThread => {
                 command_is_executing.unblock_input_thread();
-            }
+            },
             ClientInstruction::SwitchToMode(input_mode) => {
                 send_input_instructions
                     .send(InputInstruction::SwitchToMode(input_mode))
                     .unwrap();
-            }
-            _ => {}
+            },
+            _ => {},
         }
     }
 
@@ -372,3 +397,7 @@ pub fn start_client(
     let _ = stdout.write(goodbye_message.as_bytes()).unwrap();
     stdout.flush().unwrap();
 }
+
+#[cfg(test)]
+#[path = "./unit/stdin_tests.rs"]
+mod stdin_tests;
