@@ -2,7 +2,7 @@ use zellij_utils::errors::{ContextType, PtyWriteContext};
 
 use crate::thread_bus::Bus;
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Eq, PartialEq)]
 pub(crate) enum PtyWriteInstruction {
     Write(Vec<u8>, i32),
     Exit,
