@@ -474,6 +474,7 @@ fn route_action(
     should_break
 }
 
+// this should only be used for one-off startup instructions
 macro_rules! send_to_screen_or_retry_queue {
     ($rlocked_sessions:expr, $message:expr, $instruction: expr, $retry_queue:expr) => {{
         match $rlocked_sessions.as_ref() {
@@ -513,10 +514,15 @@ pub(crate) fn route_thread_main(
                             let client_id = maybe_client_id.unwrap_or(client_id);
                             if let Some(rlocked_sessions) = rlocked_sessions.as_ref() {
                                 if let Action::SwitchToMode(input_mode) = action {
-                                    os_input.send_to_client(
+                                    let send_res = os_input.send_to_client(
                                         client_id,
                                         ServerToClientMsg::SwitchToMode(input_mode),
                                     );
+                                    if send_res.is_err() {
+                                        let _ = to_server
+                                            .send(ServerInstruction::RemoveClient(client_id));
+                                        return true;
+                                    }
                                 }
                                 if route_action(
                                     action,
@@ -547,7 +553,6 @@ pub(crate) fn route_thread_main(
                                 .unwrap();
                         },
                         ClientToServerMsg::TerminalPixelDimensions(pixel_dimensions) => {
-                            // this is experimental, please be cautious implementing this elsewhere
                             send_to_screen_or_retry_queue!(
                                 rlocked_sessions,
                                 ScreenInstruction::TerminalPixelDimensions(pixel_dimensions),
@@ -555,35 +560,33 @@ pub(crate) fn route_thread_main(
                                 retry_queue
                             );
                         },
-                        ClientToServerMsg::BackgroundColor(background_color_instruction) => {
-                            rlocked_sessions
-                                .as_ref()
-                                .unwrap()
-                                .senders
-                                .send_to_screen(ScreenInstruction::TerminalBackgroundColor(
-                                    background_color_instruction,
-                                ))
-                                .unwrap();
+                        ClientToServerMsg::BackgroundColor(ref background_color_instruction) => {
+                            send_to_screen_or_retry_queue!(
+                                rlocked_sessions,
+                                ScreenInstruction::TerminalBackgroundColor(
+                                    background_color_instruction.clone()
+                                ),
+                                instruction,
+                                retry_queue
+                            );
                         },
-                        ClientToServerMsg::ForegroundColor(foreground_color_instruction) => {
-                            rlocked_sessions
-                                .as_ref()
-                                .unwrap()
-                                .senders
-                                .send_to_screen(ScreenInstruction::TerminalForegroundColor(
-                                    foreground_color_instruction,
-                                ))
-                                .unwrap();
+                        ClientToServerMsg::ForegroundColor(ref foreground_color_instruction) => {
+                            send_to_screen_or_retry_queue!(
+                                rlocked_sessions,
+                                ScreenInstruction::TerminalForegroundColor(
+                                    foreground_color_instruction.clone()
+                                ),
+                                instruction,
+                                retry_queue
+                            );
                         },
-                        ClientToServerMsg::ColorRegisters(color_registers) => {
-                            rlocked_sessions
-                                .as_ref()
-                                .unwrap()
-                                .senders
-                                .send_to_screen(ScreenInstruction::TerminalColorRegisters(
-                                    color_registers,
-                                ))
-                                .unwrap();
+                        ClientToServerMsg::ColorRegisters(ref color_registers) => {
+                            send_to_screen_or_retry_queue!(
+                                rlocked_sessions,
+                                ScreenInstruction::TerminalColorRegisters(color_registers.clone()),
+                                instruction,
+                                retry_queue
+                            );
                         },
                         ClientToServerMsg::NewClient(
                             client_attributes,
@@ -644,7 +647,7 @@ pub(crate) fn route_thread_main(
             },
             None => {
                 log::error!("Received empty message from client");
-                os_input.send_to_client(
+                let _ = os_input.send_to_client(
                     client_id,
                     ServerToClientMsg::Exit(ExitReason::Error(
                         "Received empty message".to_string(),
