@@ -1137,7 +1137,7 @@ pub(crate) fn screen_thread_main(
             },
             ScreenInstruction::ScrollUpAt(point, client_id) => {
                 active_tab!(screen, client_id, |tab: &mut Tab| tab
-                    .scroll_terminal_up(&point, 3, client_id));
+                    .handle_scrollwheel_up(&point, 3, client_id));
                 screen.render();
             },
             ScreenInstruction::ScrollDown(client_id) => {
@@ -1147,7 +1147,7 @@ pub(crate) fn screen_thread_main(
             },
             ScreenInstruction::ScrollDownAt(point, client_id) => {
                 active_tab!(screen, client_id, |tab: &mut Tab| tab
-                    .scroll_terminal_down(&point, 3, client_id));
+                    .handle_scrollwheel_down(&point, 3, client_id));
                 screen.render();
             },
             ScreenInstruction::ScrollToBottom(client_id) => {
