@@ -2,9 +2,8 @@ use crate::output::CharacterChunk;
 use crate::panes::{AnsiCode, CharacterStyles, TerminalCharacter, EMPTY_TERMINAL_CHARACTER};
 use crate::ui::boundaries::boundary_type;
 use crate::ClientId;
-use zellij_tile::prelude::Style;
+use zellij_utils::data::{client_id_to_colors, PaletteColor, Style};
 use zellij_utils::pane_size::Viewport;
-use zellij_utils::zellij_tile::prelude::{client_id_to_colors, PaletteColor};
 
 use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
 
@@ -18,12 +17,12 @@ fn foreground_color(characters: &str, color: Option<PaletteColor>) -> Vec<Termin
                 styles
                     .foreground(Some(AnsiCode::from(palette_color)))
                     .bold(Some(AnsiCode::On))
-            }
+            },
             None => {
                 let mut styles = CharacterStyles::new();
                 styles.reset_all();
                 styles.bold(Some(AnsiCode::On))
-            }
+            },
         };
         let terminal_character = TerminalCharacter {
             character,
@@ -45,12 +44,12 @@ fn background_color(characters: &str, color: Option<PaletteColor>) -> Vec<Termin
                 styles
                     .background(Some(AnsiCode::from(palette_color)))
                     .bold(Some(AnsiCode::On))
-            }
+            },
             None => {
                 let mut styles = CharacterStyles::new();
                 styles.reset_all();
                 styles
-            }
+            },
         };
         let terminal_character = TerminalCharacter {
             character,
@@ -566,7 +565,7 @@ impl PaneFrame {
                 ),
             (Some((left_side, left_side_len)), None) => {
                 self.left_and_middle_title_line(left_side, &left_side_len, middle, middle_len)
-            }
+            },
             _ => self.middle_only_title_line(middle, middle_len),
         }
     }
@@ -580,10 +579,10 @@ impl PaneFrame {
         match (left_side, right_side) {
             (Some((left_side, left_side_len)), Some((right_side, right_side_len))) => {
                 self.two_part_title_line(left_side, &left_side_len, right_side, &right_side_len)
-            }
+            },
             (Some((left_side, left_side_len)), None) => {
                 self.left_only_title_line(left_side, &left_side_len)
-            }
+            },
             _ => self.empty_title_line(),
         }
     }
