@@ -295,8 +295,13 @@ pub enum ScreenContext {
     ChangeMode,
     LeftClick,
     RightClick,
-    MouseRelease,
-    MouseHold,
+    MiddleClick,
+    LeftMouseRelease,
+    RightMouseRelease,
+    MiddleMouseRelease,
+    MouseHoldLeft,
+    MouseHoldRight,
+    MouseHoldMiddle,
     Copy,
     ToggleTab,
     AddClient,
