@@ -1,10 +1,10 @@
 //! Handles cli and configuration options
 use crate::cli::Command;
+use crate::data::InputMode;
 use clap::{ArgEnum, Args};
 use serde::{Deserialize, Serialize};
 use std::path::PathBuf;
 use std::str::FromStr;
-use zellij_tile::data::InputMode;
 
 #[derive(Copy, Clone, Debug, PartialEq, Deserialize, Serialize, ArgEnum)]
 pub enum OnForceClose {
@@ -40,58 +40,71 @@ impl FromStr for OnForceClose {
 pub struct Options {
     /// Allow plugins to use a more simplified layout
     /// that is compatible with more fonts (true or false)
-    #[clap(long)]
+    #[clap(long, value_parser)]
     #[serde(default)]
     pub simplified_ui: Option<bool>,
     /// Set the default theme
-    #[clap(long)]
+    #[clap(long, value_parser)]
     pub theme: Option<String>,
     /// Set the default mode
-    #[clap(long, arg_enum, hide_possible_values = true)]
+    #[clap(long, arg_enum, hide_possible_values = true, value_parser)]
     pub default_mode: Option<InputMode>,
     /// Set the default shell
-    #[clap(long, parse(from_os_str))]
+    #[clap(long, value_parser)]
     pub default_shell: Option<PathBuf>,
+    /// Set the default layout
+    #[clap(long, value_parser)]
+    pub default_layout: Option<PathBuf>,
     /// Set the layout_dir, defaults to
     /// subdirectory of config dir
-    #[clap(long, parse(from_os_str))]
+    #[clap(long, value_parser)]
     pub layout_dir: Option<PathBuf>,
-    #[clap(long)]
+    /// Set the theme_dir, defaults to
+    /// subdirectory of config dir
+    #[clap(long, value_parser)]
+    pub theme_dir: Option<PathBuf>,
+    #[clap(long, value_parser)]
     #[serde(default)]
     /// Set the handling of mouse events (true or false)
     /// Can be temporarily bypassed by the [SHIFT] key
     pub mouse_mode: Option<bool>,
-    #[clap(long)]
+    #[clap(long, value_parser)]
     #[serde(default)]
     /// Set display of the pane frames (true or false)
     pub pane_frames: Option<bool>,
-    #[clap(long)]
+    #[clap(long, value_parser)]
     #[serde(default)]
     /// Mirror session when multiple users are connected (true or false)
     pub mirror_session: Option<bool>,
     /// Set behaviour on force close (quit or detach)
-    #[clap(long, arg_enum, hide_possible_values = true)]
+    #[clap(long, arg_enum, hide_possible_values = true, value_parser)]
     pub on_force_close: Option<OnForceClose>,
-    #[clap(long)]
+    #[clap(long, value_parser)]
     pub scroll_buffer_size: Option<usize>,
 
     /// Switch to using a user supplied command for clipboard instead of OSC52
-    #[clap(long)]
+    #[clap(long, value_parser)]
     #[serde(default)]
     pub copy_command: Option<String>,
 
     /// OSC52 destination clipboard
-    #[clap(long, arg_enum, ignore_case = true, conflicts_with = "copy-command")]
+    #[clap(
+        long,
+        arg_enum,
+        ignore_case = true,
+        conflicts_with = "copy-command",
+        value_parser
+    )]
     #[serde(default)]
     pub copy_clipboard: Option<Clipboard>,
 
     /// Automatically copy when selecting text (true or false)
-    #[clap(long)]
+    #[clap(long, value_parser)]
     #[serde(default)]
     pub copy_on_select: Option<bool>,
 
     /// Explicit full path to open the scrollback editor (default is $EDITOR or $VISUAL)
-    #[clap(long, parse(from_os_str))]
+    #[clap(long, value_parser)]
     pub scrollback_editor: Option<PathBuf>,
 }
 
@@ -119,7 +132,7 @@ impl Options {
     }
 
     /// Merges two [`Options`] structs, a `Some` in `other`
-    /// will supercede a `Some` in `self`
+    /// will supersede a `Some` in `self`
     // TODO: Maybe a good candidate for a macro?
     pub fn merge(&self, other: Options) -> Options {
         let mouse_mode = other.mouse_mode.or(self.mouse_mode);
@@ -128,7 +141,9 @@ impl Options {
         let simplified_ui = other.simplified_ui.or(self.simplified_ui);
         let default_mode = other.default_mode.or(self.default_mode);
         let default_shell = other.default_shell.or_else(|| self.default_shell.clone());
+        let default_layout = other.default_layout.or_else(|| self.default_layout.clone());
         let layout_dir = other.layout_dir.or_else(|| self.layout_dir.clone());
+        let theme_dir = other.theme_dir.or_else(|| self.theme_dir.clone());
         let theme = other.theme.or_else(|| self.theme.clone());
         let on_force_close = other.on_force_close.or(self.on_force_close);
         let scroll_buffer_size = other.scroll_buffer_size.or(self.scroll_buffer_size);
@@ -144,7 +159,9 @@ impl Options {
             theme,
             default_mode,
             default_shell,
+            default_layout,
             layout_dir,
+            theme_dir,
             mouse_mode,
             pane_frames,
             mirror_session,
@@ -158,7 +175,7 @@ impl Options {
     }
 
     /// Merges two [`Options`] structs,
-    /// - `Some` in `other` will supercede a `Some` in `self`
+    /// - `Some` in `other` will supersede a `Some` in `self`
     /// - `Some(bool)` in `other` will toggle a `Some(bool)` in `self`
     // TODO: Maybe a good candidate for a macro?
     pub fn merge_from_cli(&self, other: Options) -> Options {
@@ -179,7 +196,9 @@ impl Options {
 
         let default_mode = other.default_mode.or(self.default_mode);
         let default_shell = other.default_shell.or_else(|| self.default_shell.clone());
+        let default_layout = other.default_layout.or_else(|| self.default_layout.clone());
         let layout_dir = other.layout_dir.or_else(|| self.layout_dir.clone());
+        let theme_dir = other.theme_dir.or_else(|| self.theme_dir.clone());
         let theme = other.theme.or_else(|| self.theme.clone());
         let on_force_close = other.on_force_close.or(self.on_force_close);
         let scroll_buffer_size = other.scroll_buffer_size.or(self.scroll_buffer_size);
@@ -195,7 +214,9 @@ impl Options {
             theme,
             default_mode,
             default_shell,
+            default_layout,
             layout_dir,
+            theme_dir,
             mouse_mode,
             pane_frames,
             mirror_session,
@@ -222,10 +243,10 @@ impl Options {
 /// boolean flags end up toggling boolean options in `Options`
 pub struct CliOptions {
     /// Disable handling of mouse events
-    #[clap(long, conflicts_with("mouse-mode"))]
+    #[clap(long, conflicts_with("mouse-mode"), value_parser)]
     pub disable_mouse_mode: bool,
     /// Disable display of pane frames
-    #[clap(long, conflicts_with("pane-frames"))]
+    #[clap(long, conflicts_with("pane-frames"), value_parser)]
     pub no_pane_frames: bool,
     #[clap(flatten)]
     options: Options,
@@ -247,7 +268,9 @@ impl From<CliOptions> for Options {
             theme: opts.theme,
             default_mode: opts.default_mode,
             default_shell: opts.default_shell,
+            default_layout: opts.default_layout,
             layout_dir: opts.layout_dir,
+            theme_dir: opts.theme_dir,
             mouse_mode: opts.mouse_mode,
             pane_frames: opts.pane_frames,
             mirror_session: opts.mirror_session,
