@@ -2,21 +2,26 @@
 
 use std::{iter, str::from_utf8};
 
+use crate::data::{Palette, PaletteColor, PaletteSource, ThemeHue};
 use crate::envs::get_session_name;
 use colorsys::Rgb;
-use std::os::unix::fs::PermissionsExt;
-use std::path::Path;
-use std::{fs, io};
 use strip_ansi_escapes::strip;
 use unicode_width::UnicodeWidthStr;
-use zellij_tile::data::{Palette, PaletteColor, PaletteSource, ThemeHue};
 
-const UNIX_PERMISSIONS: u32 = 0o700;
+#[cfg(unix)]
+pub use unix_only::*;
 
-pub fn set_permissions(path: &Path) -> io::Result<()> {
-    let mut permissions = fs::metadata(path)?.permissions();
-    permissions.set_mode(UNIX_PERMISSIONS);
-    fs::set_permissions(path, permissions)
+#[cfg(unix)]
+mod unix_only {
+    use std::os::unix::fs::PermissionsExt;
+    use std::path::Path;
+    use std::{fs, io};
+
+    pub fn set_permissions(path: &Path, mode: u32) -> io::Result<()> {
+        let mut permissions = fs::metadata(path)?.permissions();
+        permissions.set_mode(mode);
+        fs::set_permissions(path, permissions)
+    }
 }
 
 pub fn ansi_len(s: &str) -> usize {
@@ -114,7 +119,7 @@ pub fn detect_theme_hue(bg: PaletteColor) -> ThemeHue {
                 true => ThemeHue::Light,
                 false => ThemeHue::Dark,
             }
-        }
+        },
         _ => ThemeHue::Dark,
     }
 }
